@@ -24,77 +24,38 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-iot-sqs`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.iotsqs`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS IoT MQTT topic rule and an AWS SQS Queue pattern.
 
-Here is a minimal deployable pattern definition:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { IotToSqsProps, IotToSqs } from '@aws-solutions-constructs/aws-iot-sqs';
+const { IotToSqsProps, IotToSqs } from '@aws-solutions-constructs/aws-iot-sqs';
 
-const constructProps: IotToSqsProps = {
-  iotTopicRuleProps: {
-    topicRulePayload: {
-      ruleDisabled: false,
-      description: "Testing the IotToSqs Pattern",
-      sql: "SELECT * FROM 'iot/sqs/#'",
-      actions: []
+const props: IotToSqsProps = {
+    iotTopicRuleProps: {
+        topicRulePayload: {
+            ruleDisabled: false,
+            description: "Testing the IotToSqs Pattern",
+            sql: "SELECT * FROM 'iot/sqs/#'",
+            actions: []
+        }
     }
-  }
 };
 
-new IotToSqs(this, 'test-iot-sqs-integration', constructProps);
+new IotToSqs(this, 'test-iot-sqs-integration', props);
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_iot_sqs import IotToSqs
-from aws_cdk import (
-    aws_iot as iot,
-    Stack
-)
-from constructs import Construct
-
-IotToSqs(self, 'test_iot_sqs',
-    iot_topic_rule_props=iot.CfnTopicRuleProps(
-        topic_rule_payload=iot.CfnTopicRule.TopicRulePayloadProperty(
-            rule_disabled=False,
-            description="Testing the IotToSqs Pattern",
-            sql="SELECT * FROM 'iot/sqs/#'",
-            actions=[]
-        )
-    ))
+```text
+new IotToSqs(scope: Construct, id: string, props: IotToSqsProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-import java.util.List;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.iot.*;
-import software.amazon.awscdk.services.iot.CfnTopicRule.TopicRulePayloadProperty;
-import software.amazon.awsconstructs.services.iotsqs.*;
-
-new IotToSqs(this, "test_iot_sqs", new IotToSqsProps.Builder()
-        .iotTopicRuleProps(new CfnTopicRuleProps.Builder()
-                .topicRulePayload(new TopicRulePayloadProperty.Builder()
-                        .ruleDisabled(false)
-                        .description("Testing the IotToSqs Pattern")
-                        .sql("SELECT * FROM 'iot/sqs/#'")
-                        .actions(List.of())
-                        .build())
-                .build())
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`IotToSqsProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -145,7 +106,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -157,36 +118,34 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_iam
 import aws_cdk.aws_iot
 import aws_cdk.aws_kms
 import aws_cdk.aws_sqs
-import aws_cdk.core
+import constructs
 
 
 class IotToSqs(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-iot-sqs.IotToSqs",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
+        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -204,25 +163,6 @@ class IotToSqs(
         :access: public
         :summary: Constructs a new instance of the IotToSqs class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToSqsProps(
             iot_topic_rule_props=iot_topic_rule_props,
             dead_letter_queue_props=dead_letter_queue_props,
@@ -237,27 +177,27 @@ class IotToSqs(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="iotActionsRole")
     def iot_actions_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "iotActionsRole"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="iotTopicRule")
     def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
         return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="encryptionKey")
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], jsii.get(self, "encryptionKey"))
@@ -282,15 +222,15 @@ class IotToSqsProps:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
+        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+        encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         '''
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
@@ -313,30 +253,6 @@ class IotToSqsProps:
             encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
-        if __debug__:
-            def stub(
-                *,
-                iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
-            check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
-            check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
-            check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
-            check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
-            check_type(argname="argument encryption_key_props", value=encryption_key_props, expected_type=type_hints["encryption_key_props"])
-            check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
-            check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
-            check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
