@@ -8,21 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_iot._jsii
-import aws_cdk.aws_kms._jsii
-import aws_cdk.aws_sqs._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-iot-sqs",
-    "1.174.0",
+    "2.2.0",
     __name__[0:-6],
-    "aws-iot-sqs@1.174.0.jsii.tgz",
+    "aws-iot-sqs@2.2.0.jsii.tgz",
 )
 
 __all__ = [
